Changelog
---------

Log of changes to `django-icons`


0.0.2 - 2017-06-22
==================

- Bug fixes
- More tests
- More documentation


0.0.2 - 2017-06-19
==================

- Updated docs and tests
- Demo of custom SVG renderer included
- FontAwesome and Bootstrap3 renderers included
- New structure for settings dict
- First documentation, linked to ReadTheDocs
- First tests
- Introducing the `icon` template tag


0.0.1 - 2017-06-15
==================

- First publication on GitHub and PyPI
- Non-functional, just names and tests